package eewer.com.bbtop;

import javax.swing.*;
import java.awt.*;
import java.awt.event.WindowEvent;
import java.awt.event.WindowFocusListener;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

public class BlinkingTitleFrame {
    private static boolean hasFocus = true; // Track focus state
    private static boolean blinkState = false; // Toggle for blinking

    public static void main(String[] args) {
        // Create the frame
        JFrame frame = new JFrame();
        
        // Set frame to always stay on top
        frame.setAlwaysOnTop(true);
        
        // Basic frame setup
        frame.setSize(400, 300);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setLocationRelativeTo(null);
        
        // Timer for updating title (every 500ms for blinking effect)
        Timer timer = new Timer(500, e -> {
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
            String dateTime = LocalDateTime.now().format(formatter);
            
            if (hasFocus) {
                // Normal state when focused
                frame.setTitle("当前时间: " + dateTime);
            } else {
                // Blinking effect when not focused
                blinkState = !blinkState;
                if (blinkState) {
                    frame.setTitle("⚠️ 当前时间: " + dateTime + " ⚠️"); // Attention with symbols
                } else {
                    frame.setTitle("当前时间: " + dateTime); // Normal state
                }
            }
        });
        
        // Add focus listener
        frame.addWindowFocusListener(new WindowFocusListener() {
            @Override
            public void windowGainedFocus(WindowEvent e) {
                hasFocus = true;
                blinkState = false; // Reset blink state
                frame.setTitle("当前时间: " + LocalDateTime.now()
                    .format(DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss")));
            }

            @Override
            public void windowLostFocus(WindowEvent e) {
                hasFocus = false;
            }
        });
        
        // Create JTextArea with Chinese font
        JTextArea textArea = new JTextArea();
        textArea.setFont(new Font("Microsoft YaHei", Font.PLAIN, 20));
        textArea.setText("这是一个示例文本\n包含中文字符\n你可以编辑它！");
        textArea.setLineWrap(true);
        textArea.setWrapStyleWord(true);
        
        // Add scroll pane
        frame.add(new JScrollPane(textArea), BorderLayout.CENTER);
        
        // Start the timer
        timer.start();
        
        // Make frame visible
        frame.setVisible(true);
    }
}
