package eewer.com.bbtop;

import javax.swing.*;
import java.awt.*;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowFocusListener;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

public class ColorTitleFrame {
	private static boolean hasFocus = true;
	private static JLabel titleLabel; // Custom title bar label
	private static Point initialClick; // For dragging

	private static String title = "防剪切,防搬运, 抖音: @ifoxbin ";

	public static void main(String[] args) {

		// Add this before setting the font to check available fonts
		GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
		String[] fontNames = ge.getAvailableFontFamilyNames();
		for (String fontName : fontNames) {
			if (fontName.contains("YaHei") || fontName.contains("SimSun") || fontName.contains("Noto")) {
				System.out.println("Found suitable font: " + fontName);
			}
		}

		String preferredFont = "Microsoft YaHei"; // Default
		for (String fontName : fontNames) {
			if (fontName.equals("Microsoft YaHei") || fontName.equals("Noto Sans CJK SC")) {
				preferredFont = fontName;
				break;
			}
		}
		// textArea.setFont(new Font(preferredFont, Font.PLAIN, 20));

		// Create the frame
		JFrame frame = new JFrame();
		frame.setUndecorated(true); // Remove default title bar
		frame.setAlwaysOnTop(true);
		frame.setSize(400, 300);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setLocationRelativeTo(null);

		// Custom title bar
		JPanel titleBar = new JPanel();
		titleBar.setBackground(Color.DARK_GRAY);
		titleBar.setPreferredSize(new Dimension(400, 50));
		titleBar.setLayout(new BorderLayout());

		// Title label
		titleLabel = new JLabel(title, JLabel.CENTER);
		titleLabel.setForeground(Color.WHITE);
		titleLabel.setFont(new Font(preferredFont, Font.BOLD, 20));
		titleBar.add(titleLabel, BorderLayout.CENTER);

		// Add dragging functionality to title bar
		titleBar.addMouseListener(new MouseAdapter() {
			public void mousePressed(MouseEvent e) {
				initialClick = e.getPoint();
			}
		});
		titleBar.addMouseMotionListener(new MouseAdapter() {
			public void mouseDragged(MouseEvent e) {
				int x = frame.getLocation().x + e.getX() - initialClick.x;
				int y = frame.getLocation().y + e.getY() - initialClick.y;
				frame.setLocation(x, y);
			}
		});

		// Close button
		JButton closeButton = new JButton("✖");
		closeButton.setForeground(Color.WHITE);
		closeButton.setBackground(Color.DARK_GRAY);
		closeButton.setBorderPainted(false);
		closeButton.addActionListener(e -> System.exit(0));
		titleBar.add(closeButton, BorderLayout.EAST);

		// Timer for updating title and color
		Timer timer = new Timer(500, e -> {
			DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
			String dateTime = LocalDateTime.now().format(formatter);

			if (hasFocus) {
				titleLabel.setForeground(Color.WHITE); // Normal color
				titleLabel.setText(title + dateTime);
			} else {
				// Toggle color for blinking effect
				titleLabel.setForeground(titleLabel.getForeground() == Color.RED ? Color.YELLOW : Color.RED);
				titleLabel.setText(title + dateTime + "");
			}
		});

		// Focus listener
		frame.addWindowFocusListener(new WindowFocusListener() {
			@Override
			public void windowGainedFocus(WindowEvent e) {
				hasFocus = true;
				titleLabel.setForeground(Color.WHITE);
			}

			@Override
			public void windowLostFocus(WindowEvent e) {
				hasFocus = false;
			}
		});

		// Text area
		JTextArea textArea = new JTextArea();
		textArea.setFont(new Font(preferredFont, Font.PLAIN, 30));
		textArea.setText("这是一个示例文本\n包含中文字符\n你可以编辑它！");
		textArea.setLineWrap(true);
		textArea.setWrapStyleWord(true);

		// Main panel with custom title bar and content
		JPanel mainPanel = new JPanel(new BorderLayout());
		mainPanel.add(titleBar, BorderLayout.NORTH);
		mainPanel.add(new JScrollPane(textArea), BorderLayout.CENTER);
		frame.add(mainPanel);

		// Start timer and show frame
		timer.start();
		frame.setVisible(true);
	}
}
