package eewer.com.bbtop;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

public class ResizableColorTitleFrame {
	private static boolean hasFocus = true;
	private static JLabel titleLabel;
	private static Point initialClick;
	private static final int RESIZE_WIDTH = 5; // Width of resize border
	private static boolean isResizing = false;
	private static int resizeDirection;

	// Constants for resize directions
	private static final int NORTH = 1;
	private static final int SOUTH = 2;
	private static final int EAST = 3;
	private static final int WEST = 4;
	private static final int NORTH_EAST = 5;
	private static final int NORTH_WEST = 6;
	private static final int SOUTH_EAST = 7;
	private static final int SOUTH_WEST = 8;

	private static String title = "抖音: @ifoxbin 防剪切,防搬运 ";

	public static void main(String[] args) {

		// Add this before setting the font to check available fonts
		GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
		String[] fontNames = ge.getAvailableFontFamilyNames();
		for (String fontName : fontNames) {
			if (fontName.contains("YaHei") || fontName.contains("SimSun") || fontName.contains("Noto")) {
				System.out.println("Found suitable font: " + fontName);
			}
		}

		String preferredFont = "Microsoft YaHei"; // Default
		for (String fontName : fontNames) {
			if (fontName.equals("Microsoft YaHei") || fontName.equals("Noto Sans CJK SC")) {
				preferredFont = fontName;
				break;
			}
		}
		// textArea.setFont(new Font(preferredFont, Font.PLAIN, 20));

		// Create the frame
		JFrame frame = new JFrame();
		frame.setUndecorated(true);
		frame.setAlwaysOnTop(true);
		frame.setSize(466, 60);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setLocationRelativeTo(null);
		frame.setMinimumSize(new Dimension(100, 50)); // Minimum size

		// Custom title bar
		JPanel titleBar = new JPanel();
		titleBar.setBackground(Color.LIGHT_GRAY);
		titleBar.setPreferredSize(new Dimension(466, 30));
		titleBar.setLayout(new BorderLayout());

		// Title label
		titleLabel = new JLabel(title, JLabel.CENTER);
		titleLabel.setForeground(Color.BLUE);
		titleLabel.setFont(new Font(preferredFont, Font.BOLD, 16));
		titleBar.add(titleLabel, BorderLayout.CENTER);

		// Close button
		JButton closeButton = new JButton("✖");
		closeButton.setForeground(Color.BLUE);
		closeButton.setBackground(Color.LIGHT_GRAY);
		closeButton.setBorderPainted(false);
		closeButton.addActionListener(e -> System.exit(0));
		titleBar.add(closeButton, BorderLayout.EAST);

		// Timer for updating title and color
		Timer timer = new Timer(500, e -> {
			DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
			String dateTime = LocalDateTime.now().format(formatter);
			if (hasFocus) {
				titleLabel.setForeground(Color.BLUE);
				titleLabel.setText(title + dateTime);
			} else {
				titleLabel.setForeground(titleLabel.getForeground() == Color.RED ? Color.BLUE : Color.RED);
				titleLabel.setText(title + dateTime + "");
			}
		});

		// Focus listener
		frame.addWindowFocusListener(new WindowFocusListener() {
			@Override
			public void windowGainedFocus(WindowEvent e) {
				hasFocus = true;
				titleLabel.setForeground(Color.BLUE);
			}

			@Override
			public void windowLostFocus(WindowEvent e) {
				hasFocus = false;
			}
		});

		// Text area
		JTextArea textArea = new JTextArea();
		textArea.setFont(new Font(title, Font.PLAIN, 20));
		textArea.setText("又来拍视频啦\n包含中文字符\n你可以编辑它！");
		textArea.setLineWrap(true);
		textArea.setWrapStyleWord(true);

		// Main panel
		JPanel mainPanel = new JPanel(new BorderLayout());
		mainPanel.add(titleBar, BorderLayout.NORTH);
		mainPanel.add(new JScrollPane(textArea), BorderLayout.CENTER);
		frame.add(mainPanel);

		// Mouse listeners for dragging and resizing
		MouseAdapter mouseAdapter = new MouseAdapter() {
			@Override
			public void mousePressed(MouseEvent e) {
				initialClick = e.getPoint();
				resizeDirection = getResizeDirection(frame, e.getPoint());
				isResizing = resizeDirection != 0;
			}

			@Override
			public void mouseDragged(MouseEvent e) {
				if (isResizing) {
					resizeFrame(frame, e.getPoint());
				} else if (e.getSource() == titleBar) {
					// Dragging the title bar
					int x = frame.getLocation().x + e.getX() - initialClick.x;
					int y = frame.getLocation().y + e.getY() - initialClick.y;
					frame.setLocation(x, y);
				}
			}

			@Override
			public void mouseMoved(MouseEvent e) {
				int direction = getResizeDirection(frame, e.getPoint());
				setCursor(frame, direction);
			}
		};

		frame.addMouseListener(mouseAdapter);
		frame.addMouseMotionListener(mouseAdapter);
		titleBar.addMouseListener(mouseAdapter);
		titleBar.addMouseMotionListener(mouseAdapter);

		// Start timer and show frame
		timer.start();
		frame.setVisible(true);
	}

	// Determine resize direction based on mouse position
	private static int getResizeDirection(JFrame frame, Point p) {
		int x = (int) p.getX();
		int y = (int) p.getY();
		int width = frame.getWidth();
		int height = frame.getHeight();

		boolean north = y < RESIZE_WIDTH;
		boolean south = y > height - RESIZE_WIDTH;
		boolean east = x > width - RESIZE_WIDTH;
		boolean west = x < RESIZE_WIDTH;

		if (north && east)
			return NORTH_EAST;
		if (north && west)
			return NORTH_WEST;
		if (south && east)
			return SOUTH_EAST;
		if (south && west)
			return SOUTH_WEST;
		if (north)
			return NORTH;
		if (south)
			return SOUTH;
		if (east)
			return EAST;
		if (west)
			return WEST;
		return 0; // No resize
	}

	// Set cursor based on resize direction
	private static void setCursor(JFrame frame, int direction) {
		switch (direction) {
		case NORTH:
		case SOUTH:
			frame.setCursor(Cursor.getPredefinedCursor(Cursor.N_RESIZE_CURSOR));
			break;
		case EAST:
		case WEST:
			frame.setCursor(Cursor.getPredefinedCursor(Cursor.E_RESIZE_CURSOR));
			break;
		case NORTH_EAST:
		case SOUTH_WEST:
			frame.setCursor(Cursor.getPredefinedCursor(Cursor.NE_RESIZE_CURSOR));
			break;
		case NORTH_WEST:
		case SOUTH_EAST:
			frame.setCursor(Cursor.getPredefinedCursor(Cursor.NW_RESIZE_CURSOR));
			break;
		default:
			frame.setCursor(Cursor.getDefaultCursor());
		}
	}

	// Resize the frame based on mouse movement
	private static void resizeFrame(JFrame frame, Point p) {
		int x = frame.getX();
		int y = frame.getY();
		int width = frame.getWidth();
		int height = frame.getHeight();
		Dimension minSize = frame.getMinimumSize();

		switch (resizeDirection) {
		case NORTH:
			height -= p.y - initialClick.y;
			y += p.y - initialClick.y;
			break;
		case SOUTH:
			height = p.y;
			break;
		case EAST:
			width = p.x;
			break;
		case WEST:
			width -= p.x - initialClick.x;
			x += p.x - initialClick.x;
			break;
		case NORTH_EAST:
			height -= p.y - initialClick.y;
			y += p.y - initialClick.y;
			width = p.x;
			break;
		case NORTH_WEST:
			height -= p.y - initialClick.y;
			y += p.y - initialClick.y;
			width -= p.x - initialClick.x;
			x += p.x - initialClick.x;
			break;
		case SOUTH_EAST:
			height = p.y;
			width = p.x;
			break;
		case SOUTH_WEST:
			height = p.y;
			width -= p.x - initialClick.x;
			x += p.x - initialClick.x;
			break;
		}

		// Enforce minimum size
		width = Math.max(width, minSize.width);
		height = Math.max(height, minSize.height);

		frame.setBounds(x, y, width, height);
	}
}
